Enum UserSignature
#[non_exhaustive]pub enum UserSignature {
Simple(SimpleSignature),
Multisig(MultisigAggregatedSignature),
PasskeyAuthenticator(PasskeyAuthenticator),
MoveAuthenticator(MoveAuthenticator),
}Expand description
A signature from a user
A UserSignature is most commonly used to authorize the execution and
inclusion of a transaction to the blockchain.
BCS
The BCS serialized form for this type is defined by the following ABNF:
user-signature-bcs = bytes ; where the contents of the bytes are defined by <user-signature>
user-signature = simple-signature / multisig / multisig-legacy / passkey / move-authenticatorNote: Due to historical reasons, signatures are serialized slightly
different from the majority of the types in IOTA. In particular if a
signature is ever embedded in another structure it generally is serialized
as bytes meaning it has a length prefix that defines the length of
the completely serialized signature.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Simple(SimpleSignature)
Multisig(MultisigAggregatedSignature)
PasskeyAuthenticator(PasskeyAuthenticator)
MoveAuthenticator(MoveAuthenticator)
Implementations
impl UserSignature
impl UserSignature
pub fn derive_address(&self) -> Address
pub fn derive_address(&self) -> Address
Derive the Address of the signer that this signature authenticates.
impl UserSignature
impl UserSignature
pub fn as_simple(&self) -> &SimpleSignature
pub fn as_simple(&self) -> &SimpleSignature
Converts this into a simple if it is a simple variant, or panics otherwise.
pub fn as_mut_simple(&mut self) -> &mut SimpleSignature
pub fn as_mut_simple(&mut self) -> &mut SimpleSignature
Converts this into a mut simple if it is a simple variant, or panics otherwise.
pub fn as_opt_simple(&self) -> Option<&SimpleSignature>
pub fn as_opt_simple(&self) -> Option<&SimpleSignature>
Converts this into a simple if it is a simple variant, or returns None otherwise.
pub fn as_opt_mut_simple(&mut self) -> Option<&mut SimpleSignature>
pub fn as_opt_mut_simple(&mut self) -> Option<&mut SimpleSignature>
Converts this into a mut simple if it is a simple variant, or returns None otherwise.
pub fn into_opt_simple(self) -> Option<SimpleSignature>
pub fn into_opt_simple(self) -> Option<SimpleSignature>
Converts this into a simple if it is a simple variant, or returns None otherwise.
pub fn into_simple(self) -> SimpleSignature
pub fn into_simple(self) -> SimpleSignature
Converts this into a simple if it is a simple variant, or panics otherwise.
pub fn is_multisig(&self) -> bool
pub fn is_multisig(&self) -> bool
Checks if this is a multisig variant.
pub fn as_multisig(&self) -> &MultisigAggregatedSignature
pub fn as_multisig(&self) -> &MultisigAggregatedSignature
Converts this into a multisig if it is a multisig variant, or panics otherwise.
pub fn as_mut_multisig(&mut self) -> &mut MultisigAggregatedSignature
pub fn as_mut_multisig(&mut self) -> &mut MultisigAggregatedSignature
Converts this into a mut multisig if it is a multisig variant, or panics otherwise.
pub fn as_opt_multisig(&self) -> Option<&MultisigAggregatedSignature>
pub fn as_opt_multisig(&self) -> Option<&MultisigAggregatedSignature>
Converts this into a multisig if it is a multisig variant, or returns None otherwise.
pub fn as_opt_mut_multisig(
&mut self,
) -> Option<&mut MultisigAggregatedSignature>
pub fn as_opt_mut_multisig( &mut self, ) -> Option<&mut MultisigAggregatedSignature>
Converts this into a mut multisig if it is a multisig variant, or returns None otherwise.
pub fn into_opt_multisig(self) -> Option<MultisigAggregatedSignature>
pub fn into_opt_multisig(self) -> Option<MultisigAggregatedSignature>
Converts this into a multisig if it is a multisig variant, or returns None otherwise.
pub fn into_multisig(self) -> MultisigAggregatedSignature
pub fn into_multisig(self) -> MultisigAggregatedSignature
Converts this into a multisig if it is a multisig variant, or panics otherwise.
pub fn is_passkey_authenticator(&self) -> bool
pub fn is_passkey_authenticator(&self) -> bool
Checks if this is a passkey_authenticator variant.
pub fn as_passkey_authenticator(&self) -> &PasskeyAuthenticator
pub fn as_passkey_authenticator(&self) -> &PasskeyAuthenticator
Converts this into a passkey_authenticator if it is a passkey_authenticator variant, or panics otherwise.
pub fn as_mut_passkey_authenticator(&mut self) -> &mut PasskeyAuthenticator
pub fn as_mut_passkey_authenticator(&mut self) -> &mut PasskeyAuthenticator
Converts this into a mut passkey_authenticator if it is a passkey_authenticator variant, or panics otherwise.
pub fn as_opt_passkey_authenticator(&self) -> Option<&PasskeyAuthenticator>
pub fn as_opt_passkey_authenticator(&self) -> Option<&PasskeyAuthenticator>
Converts this into a passkey_authenticator if it is a passkey_authenticator variant, or returns None otherwise.
pub fn as_opt_mut_passkey_authenticator(
&mut self,
) -> Option<&mut PasskeyAuthenticator>
pub fn as_opt_mut_passkey_authenticator( &mut self, ) -> Option<&mut PasskeyAuthenticator>
Converts this into a mut passkey_authenticator if it is a passkey_authenticator variant, or returns None otherwise.
pub fn into_opt_passkey_authenticator(self) -> Option<PasskeyAuthenticator>
pub fn into_opt_passkey_authenticator(self) -> Option<PasskeyAuthenticator>
Converts this into a passkey_authenticator if it is a passkey_authenticator variant, or returns None otherwise.
pub fn into_passkey_authenticator(self) -> PasskeyAuthenticator
pub fn into_passkey_authenticator(self) -> PasskeyAuthenticator
Converts this into a passkey_authenticator if it is a passkey_authenticator variant, or panics otherwise.
pub fn is_move_authenticator(&self) -> bool
pub fn is_move_authenticator(&self) -> bool
Checks if this is a move_authenticator variant.
pub fn as_move_authenticator(&self) -> &MoveAuthenticator
pub fn as_move_authenticator(&self) -> &MoveAuthenticator
Converts this into a move_authenticator if it is a move_authenticator variant, or panics otherwise.
pub fn as_mut_move_authenticator(&mut self) -> &mut MoveAuthenticator
pub fn as_mut_move_authenticator(&mut self) -> &mut MoveAuthenticator
Converts this into a mut move_authenticator if it is a move_authenticator variant, or panics otherwise.
pub fn as_opt_move_authenticator(&self) -> Option<&MoveAuthenticator>
pub fn as_opt_move_authenticator(&self) -> Option<&MoveAuthenticator>
Converts this into a move_authenticator if it is a move_authenticator variant, or returns None otherwise.
pub fn as_opt_mut_move_authenticator(
&mut self,
) -> Option<&mut MoveAuthenticator>
pub fn as_opt_mut_move_authenticator( &mut self, ) -> Option<&mut MoveAuthenticator>
Converts this into a mut move_authenticator if it is a move_authenticator variant, or returns None otherwise.
pub fn into_opt_move_authenticator(self) -> Option<MoveAuthenticator>
pub fn into_opt_move_authenticator(self) -> Option<MoveAuthenticator>
Converts this into a move_authenticator if it is a move_authenticator variant, or returns None otherwise.
pub fn into_move_authenticator(self) -> MoveAuthenticator
pub fn into_move_authenticator(self) -> MoveAuthenticator
Converts this into a move_authenticator if it is a move_authenticator variant, or panics otherwise.
pub fn scheme(&self) -> SignatureScheme
pub fn scheme(&self) -> SignatureScheme
Return the flag for this signature scheme
pub fn to_public_key(&self) -> Result<PublicKey, InvalidSignatureScheme>
pub fn to_public_key(&self) -> Result<PublicKey, InvalidSignatureScheme>
Return the public key for this signature, if the scheme supports it.
impl UserSignature
impl UserSignature
pub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn to_base64(&self) -> String
pub fn from_bytes( bytes: impl AsRef<[u8]>, ) -> Result<UserSignature, SignatureFromBytesError>
pub fn from_base64(s: &str) -> Result<UserSignature, Error>